@@ -22,17 +22,21 @@ import java.io.File;
 import java.util.Collections;
 import java.util.List;
 import java.util.jar.Attributes;
+import java.util.jar.Attributes.Name;
 import java.util.jar.JarEntry;
 import java.util.jar.Manifest;
 
 import org.apache.maven.shared.jar.classes.JarClasses;
+import org.apache.maven.shared.jar.classes.JarVersionedRuntimes;
 import org.apache.maven.shared.jar.identification.JarIdentification;
-import org.codehaus.plexus.util.StringUtils;
 
 /**
  * Class that contains details of a single JAR file and it's entries.
  */
 public final class JarData {
+
+    private static final Name ATTR_MULTI_RELEASE = new Attributes.Name("Multi-Release");
+
     /**
      * The JAR file.
      */
@@ -43,6 +47,11 @@ public final class JarData {
      */
     private final boolean aSealed;
 
+    /**
+     * Whether the JAR file is Multi-Release.
+     */
+    private boolean multiRelease;
+
     /**
      * The hashcode for the entire file's contents.
      */
@@ -68,11 +77,21 @@ public final class JarData {
      */
     private final List<JarEntry> entries;
 
+    /**
+     * The JAR entries of the root content, when it is a multi-release JAR
+     */
+    private List<JarEntry> rootEntries;
+
     /**
      * Information about the JAR's identifying features.
      */
     private JarIdentification jarIdentification;
 
+    /**
+     * Information about the JAR's Multi-Release entries
+     */
+    private JarVersionedRuntimes versionedRuntimes;
+
     /**
      * Constructor.
      *
@@ -87,20 +106,22 @@ public final class JarData {
 
         this.entries = Collections.unmodifiableList(entries);
 
-        boolean aSealed = false;
-        if (this.manifest != null) {
-            String sval = this.manifest.getMainAttributes().getValue(Attributes.Name.SEALED);
-            if (StringUtils.isNotEmpty(sval)) {
-                aSealed = "true".equalsIgnoreCase(sval.trim());
-            }
-        }
-        this.aSealed = aSealed;
+        this.aSealed = isAttributePresent(Attributes.Name.SEALED);
+        this.multiRelease = isAttributePresent(ATTR_MULTI_RELEASE);
     }
 
     public List<JarEntry> getEntries() {
         return entries;
     }
 
+    public List<JarEntry> getRootEntries() {
+        return rootEntries;
+    }
+
+    public void setRootEntries(List<JarEntry> rootEntries) {
+        this.rootEntries = rootEntries;
+    }
+
     public Manifest getManifest() {
         return manifest;
     }
@@ -113,6 +134,10 @@ public final class JarData {
         return aSealed;
     }
 
+    public boolean isMultiRelease() {
+        return multiRelease;
+    }
+
     public void setFileHash(String fileHash) {
         this.fileHash = fileHash;
     }
@@ -141,6 +166,10 @@ public final class JarData {
         return entries.size();
     }
 
+    public int getNumRootEntries() {
+        return rootEntries.size();
+    }
+
     public int getNumClasses() {
         return jarClasses.getClassNames().size();
     }
@@ -164,4 +193,20 @@ public final class JarData {
     public JarClasses getJarClasses() {
         return jarClasses;
     }
+
+    public void setVersionedRuntimes(JarVersionedRuntimes versionedRuntimes) {
+        this.versionedRuntimes = versionedRuntimes;
+    }
+
+    public JarVersionedRuntimes getVersionedRuntimes() {
+        return this.versionedRuntimes;
+    }
+
+    private boolean isAttributePresent(Attributes.Name attrName) {
+        if (this.manifest != null) {
+            String sval = this.manifest.getMainAttributes().getValue(attrName);
+            return sval != null && "true".equalsIgnoreCase(sval.trim());
+        }
+        return false;
+    }
 }
